@@ -1,7 +1,7 @@
 """
 Type annotations for ebs service client.
 
-[Open documentation](./client.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
 
 Usage::
 
@@ -58,8 +58,8 @@ class Exceptions:
 
 class EBSClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client)
-    [Show boto3-stubs documentation](./client.md)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
     """
 
     meta: ClientMeta
@@ -67,21 +67,22 @@ class EBSClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client.can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#can_paginate)
         """
 
     def complete_snapshot(
         self,
+        *,
         SnapshotId: str,
         ChangedBlocksCount: int,
         Checksum: str = None,
         ChecksumAlgorithm: Literal["SHA256"] = None,
-        ChecksumAggregationMethod: Literal["LINEAR"] = None,
+        ChecksumAggregationMethod: Literal["LINEAR"] = None
     ) -> CompleteSnapshotResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client.complete_snapshot)
-        [Show boto3-stubs documentation](./client.md#complete_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client.complete_snapshot)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#complete_snapshot)
         """
 
     def generate_presigned_url(
@@ -92,60 +93,64 @@ class EBSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#generate_presigned_url)
         """
 
     def get_snapshot_block(
-        self, SnapshotId: str, BlockIndex: int, BlockToken: str
+        self, *, SnapshotId: str, BlockIndex: int, BlockToken: str
     ) -> GetSnapshotBlockResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client.get_snapshot_block)
-        [Show boto3-stubs documentation](./client.md#get_snapshot_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client.get_snapshot_block)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#get_snapshot_block)
         """
 
     def list_changed_blocks(
         self,
+        *,
         SecondSnapshotId: str,
         FirstSnapshotId: str = None,
         NextToken: str = None,
         MaxResults: int = None,
-        StartingBlockIndex: int = None,
+        StartingBlockIndex: int = None
     ) -> ListChangedBlocksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client.list_changed_blocks)
-        [Show boto3-stubs documentation](./client.md#list_changed_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client.list_changed_blocks)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list_changed_blocks)
         """
 
     def list_snapshot_blocks(
         self,
+        *,
         SnapshotId: str,
         NextToken: str = None,
         MaxResults: int = None,
-        StartingBlockIndex: int = None,
+        StartingBlockIndex: int = None
     ) -> ListSnapshotBlocksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
-        [Show boto3-stubs documentation](./client.md#list_snapshot_blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list_snapshot_blocks)
         """
 
     def put_snapshot_block(
         self,
+        *,
         SnapshotId: str,
         BlockIndex: int,
         BlockData: Union[bytes, IO[bytes]],
         DataLength: int,
         Checksum: str,
         ChecksumAlgorithm: Literal["SHA256"],
-        Progress: int = None,
+        Progress: int = None
     ) -> PutSnapshotBlockResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client.put_snapshot_block)
-        [Show boto3-stubs documentation](./client.md#put_snapshot_block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client.put_snapshot_block)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#put_snapshot_block)
         """
 
     def start_snapshot(
         self,
+        *,
         VolumeSize: int,
         ParentSnapshotId: str = None,
         Tags: List["TagTypeDef"] = None,
@@ -153,9 +158,9 @@ class EBSClient:
         ClientToken: str = None,
         Encrypted: bool = None,
         KmsKeyArn: str = None,
-        Timeout: int = None,
+        Timeout: int = None
     ) -> StartSnapshotResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.87/reference/services/ebs.html#EBS.Client.start_snapshot)
-        [Show boto3-stubs documentation](./client.md#start_snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.88/reference/services/ebs.html#EBS.Client.start_snapshot)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#start_snapshot)
         """
